# Require:

Base library : [react-native-code-push](https://github.com/microsoft/react-native-code-push)

- [iOS Setup](https://github.com/microsoft/react-native-code-push/blob/master/docs/setup-ios.md)

- [Android Setup](https://github.com/microsoft/react-native-code-push/blob/master/docs/setup-android.md)

# Install: 

```
yarn add https://gitlab.kyanon.digital/cao.le/react-native-codepush-loader.git
or
npm i https://gitlab.kyanon.digital/cao.le/react-native-codepush-loader.git
```

# Example Package Script (package.json)
```
    "login": "appcenter login",
    "push-ios-develop": "appcenter codepush release-react -a <App Instance> -d Develop",
    "push-android-develop": "appcenter codepush release-react -a <App Instance> -d Develop",
    "push-ios-prod": "appcenter codepush release-react -a <App Instance> -d Production",
    "push-android-prod": "appcenter codepush release-react -a <App Instance> -d Production",
    "push-dev": "yarn push-ios-develop && yarn push-android-develop",
    "push-prod": "yarn push-ios-prod && yarn push-android-prod"
```

# Props:

### **onDone: void**

### **onStatusChange: void**

### **codePushOptions: <CodePushOptions>**

### **customLoaderContainer: ViewStyleSheet**

### **customProgressContainer: ViewStyleSheet**

### **customProgressText: TextStyleSheet**

### **statusTextOptions: object**

# Usage

```js
import {CodePushProgressBar} from "react-native-codepush-loader"
import CodePush, { CodePushOptions } from "react-native-code-push";

...
<CodePushProgressBar
    onDone ={ () => {
        console.log("#code push update package done");
        // CodePush.restartApp();
    }}
    onStatusChange ={ (status) => {
        console.log(status);
    }}
    codePushOptions = {{
        checkFrequency: CodePush.CheckFrequency.ON_APP_START,
        installMode: CodePush.InstallMode.IMMEDIATE,
        mandatoryInstallMode: CodePush.InstallMode.IMMEDIATE,
        deploymentKey: Platform.select({
            ios : "EoAOysexwqyahPySPLGyUYL83VFCT23tkzACF", //codepush key ios
            android : "QowUxZVGA88rCLNymI3QS9XhS2l7Modlm7ex6",//codepush key android
        }),
        updateDialog: undefined,
    }}
    customLoaderContainer =  {{
        height: 50,
    }}
    customProgressContainer = {{
        backgroundColor: "#0f0f",
        height : 50,
    }}
    customProgressText = {{
        color: "#606",
    }}
    statusTextOptions = {{
        CHECKING_FOR_UPDATE: "CodePush.sync Checking for update",
        DOWNLOADING_PACKAGE: "CodePush.sync Downloading package",
        AWAITING_USER_ACTION: "CodePush.sync Awaiting user action",
        INSTALLING_UPDATE: "CodePush.sync Installing update",
        UP_TO_DATE: "CodePush.sync App up to date.",
        UPDATE_IGNORED: "CodePush.sync Update cancelled by user",
        UPDATE_INSTALLED:
        "CodePush.sync Update installed and will be applied on restart.",
        UNKNOWN_ERROR: "CodePush.sync An unknown error occurred",
    }}
/>
...

```

# Example:
[Example](https://gitlab.kyanon.digital/cao.le/react-native-codepush-loader/-/tree/master/example%2FCodepushComponentTest)
