/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * @format
 * @flow strict-local
 */

import React from 'react';
import type {Node} from 'react';
import {
  SafeAreaView,
  ScrollView,
  StatusBar,
  StyleSheet,
  Text,
  useColorScheme,
  Platform,
  View,
} from 'react-native';

import {
  Colors,
  DebugInstructions,
  Header,
  LearnMoreLinks,
  ReloadInstructions,
} from 'react-native/Libraries/NewAppScreen';

import {CodePushProgressBar} from "react-native-codepush-loader"
import CodePush, { CodePushOptions } from "react-native-code-push";

// import {CodePushProgressBar} from "./components/codepushcomponent"

const Section = ({children, title}): Node => {
  const isDarkMode = useColorScheme() === 'dark';
  return (
    <View style={styles.sectionContainer}>
      <Text
        style={[
          styles.sectionTitle,
          {
            color: isDarkMode ? Colors.white : Colors.black,
          },
        ]}>
        {title}
      </Text>
      <Text
        style={[
          styles.sectionDescription,
          {
            color: isDarkMode ? Colors.light : Colors.dark,
          },
        ]}>
        {children}
      </Text>
    </View>
  );
}; 

const App: () => Node = () => {
  const isDarkMode = useColorScheme() === 'dark';

  const backgroundStyle = {
    backgroundColor: isDarkMode ? Colors.darker : Colors.lighter,
  };

  return (
    <SafeAreaView style={backgroundStyle}>
      <StatusBar barStyle={isDarkMode ? 'light-content' : 'dark-content'} />
      <ScrollView
        contentInsetAdjustmentBehavior="automatic"
        style={backgroundStyle}>
        <Header />
        <View
          style={{
            backgroundColor: isDarkMode ? Colors.black : Colors.white,
          }}>
       <View style={{height : 50, borderWidth : StyleSheet.hairlineWidth * 2}}>
       <CodePushProgressBar
        onDone ={ () => {
            console.log("#code push update package done");
            // CodePush.restartApp();
        }}
        onStatusChange ={ (status) => {
            console.log(status);
        }}
        codePushOptions = {{
            checkFrequency: CodePush.CheckFrequency.ON_APP_START,
            installMode: CodePush.InstallMode.IMMEDIATE,
            mandatoryInstallMode: CodePush.InstallMode.IMMEDIATE,
            deploymentKey: Platform.select({
                ios : "EoAOysexwqyahPySPLGyUYL83VFCT23tkzACF", //codepush key ios
                android : "QowUxZVGA88rCLNymI3QS9XhS2l7Modlm7ex6",//codepush key android
            }),
            updateDialog: undefined,
        }}
        customLoaderContainer =  {{
          height: 50,
        }}
        customProgressContainer = {{
            backgroundColor: "#0f0f",
            height : 50,
        }}
        customProgressText = {{
            color: "#606",
        }}
        statusTextOptions = {{
          CHECKING_FOR_UPDATE: "CodePush.sync Checking for update",
          DOWNLOADING_PACKAGE: "CodePush.sync Downloading package",
          AWAITING_USER_ACTION: "CodePush.sync Awaiting user action",
          INSTALLING_UPDATE: "CodePush.sync Installing update",
          UP_TO_DATE: "CodePush.sync App up to date.",
          UPDATE_IGNORED: "CodePush.sync Update cancelled by user",
          UPDATE_INSTALLED:
            "CodePush.sync Update installed and will be applied on restart.",
          UNKNOWN_ERROR: "CodePush.sync An unknown error occurred",
        }}
        />
       </View>
        </View>
      </ScrollView>
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  sectionContainer: {
    marginTop: 32,
    paddingHorizontal: 24,
  },
  sectionTitle: {
    fontSize: 24,
    fontWeight: '600',
  },
  sectionDescription: {
    marginTop: 8,
    fontSize: 18,
    fontWeight: '400',
  },
  highlight: {
    fontWeight: '700',
  },
});

export default App;
